%  Solow saving

clc
clear all

global sigma psi chi alpha gamma beta delta kappa omega yBar T gs StatVars g

MaxFunEvals=5000;
MaxIter=10;
gCase=1;  %   1 for gradual decline of G; 2 for actual stimulus; 3 for alt stimulus
options=optimset('Display','iter','MaxFunEvals',MaxFunEvals,'MaxIter',MaxIter,'Algorithm','levenberg-marquardt','TolFun',.00000000001,'TolX',.000000001);
%  Row of params = [sigma, psi, chi, gamma, kappa, omega, gCase]
params=[
    0.4,1.54,0.334,1.103,0,0.7,1;
    ];
sz=size(params);
Ncase=sz(1);
Nparams=sz(2);
NVars=11;
Stats=[];
for icase=1:Ncase
    sigma=params(icase,1);
    psi=params(icase,2);
    chi=params(icase,3);
    gamma=params(icase,4);
    kappa=params(icase,5);
    omega=params(icase,6);
    gCase=params(icase,7);
    beta=0.95^0.25;
    delta=0.1/4;
    alpha=0.7;
    phi=.7^0.25;
    T=80;
    
    %  Static solution
    
    g=0.2;
    x=[1;1;10];
    MaxFunEvals=50000;
    MaxIter=500;
    options=optimset('Display','iter','MaxFunEvals',MaxFunEvals,'MaxIter',MaxIter,'Algorithm','levenberg-marquardt','TolFun',.00000000001,'TolX',.000000001);
    xNew=fsolve(@StatModel,x,options);
    resNew=StatModel(xNew);
    c=xNew(1);
    h=xNew(2);
    k=xNew(3);
    muc=c^(-1/sigma)*(1-chi*(1-1/sigma)*h^(1+1/psi));
    y=h^alpha*k^(1-alpha);
    yBar=y;
    cBar=c;
    s=1-c/y;
    muh=(-chi*(1+1/psi)*c^(1-1/sigma)-gamma)*h^(1/psi);
    w=alpha*h^(alpha-1)*k^(1-alpha);
    r=(1-alpha)*h^alpha*k^(-alpha)-delta;
    StatVars=[y,h,r,w,1,c,k,0,0]; % [y,h,r,w,q,c,k,g]
    Stats=[Stats;StatVars];
    
    %  Dynamic solution
    
    % Government purchases
    
    gsS=[0.0046;0.0046;0.0046;0.0046;0.0073;0.0073;0.0073;0.0073;0.0039;0.0039;0.0039;0.0039];
    switch gCase
        case 1  %  gradual decline
            Deltag0=0.01;
            Deltag=Deltag0;
            for t=2:T
                gs(t,1)=g+Deltag;
                Deltag=Deltag*phi;
            end
        case 2  %  actual stimulus
            gs=g+yBar*[0;gsS;zeros(T-13,1)];
        case 3 %  accelerated actual stimulus
            Deltag=1;
            lambda=.7^.25;
            for t=1:12
                gAdd(t,1)=Deltag;
                Deltag=Deltag*lambda;
            end
            gs(T,1)=g;
            gs(2:13)=g+gAdd*yBar*sum(gsS)/sum(gAdd);
        case 4  %  repayment to knock out wealth effect
            Deltag0=0.001;
            Deltag=Deltag0;
            for t=2:T
                gs(t,1)=g+Deltag;
                Deltag=Deltag*phi;
            end
            repay=beta^(-T+1)*Deltag0/(1-beta*phi);
            gs(T-1)=-repay;
        case 5  %  no change in g
            gs(1:T,1)=g;
    end
    ks(1,1)=k;
    for t=2:T
        hs(t,1)=(alpha*ks(t-1)^((1-alpha)*(1+omega))*yBar^(-omega)/w)^(1/(1-alpha*(1+omega)));
        ys(t,1)=hs(t)^alpha*ks(t-1)^(1-alpha);
        cs(t,1)=(1-s)*ys(t);
        if kappa>0
            A=kappa/ks(t-1);
            B=1-kappa;
            C=kappa*ks(t-1)/2-(1-delta)*ks(t-1)-ys(t)+cs(t)+gs(t);
            ks(t,1)=(-B+(B^2-4*A*C)^.5)/(2*A);
        else
            ks(t,1)=(1-delta)*ks(t-1)+ys(t)-cs(t)-gs(t);
        end
    end
    
    Vars=[y,c,h,k,g;ys,cs,hs,ks,gs];
    if gCase<5
    mults(icase,1)=(ys(2)-yBar)/Deltag0;
    mults(icase,2)=(cs(2)-cBar)/Deltag0;
    end
end
xlswrite('Results.xlsx',Vars,'Solow');


